@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect Musical Modal Functions
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Moo;
 use strictures 2;
@@ -192,21 +192,36 @@ Music::ModalFunction - Inspect Musical Modal Functions
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
   use Music::ModalFunction ();
 
+  # What modes have a Dmaj dominant chord?
   my $m = Music::ModalFunction->new(
     chord_note   => 'd',
     chord        => 'maj',
     key_function => 'dominant',
   );
-
   my $q = $m->chord_key;
   # [[ 'chord_key', 'g', 'ionian', 'd', 'maj', 'dominant' ],
-  #  [ 'chord_key', 'g', 'lydian', 'd', 'maj', 'dominant' ]],
+  #  [ 'chord_key', 'g', 'lydian', 'd', 'maj', 'dominant' ]]
+
+  # In what modes can a Gmaj chord function as a subdominant pivot chord?
+  $m = Music::ModalFunction->new(
+    chord_note   => 'g',
+    chord        => 'maj',
+    mode_note    => 'c',
+    key_function => 'subdominant',
+  );
+  $q = $m->pivot_chord_keys;
+  # [[ 'pivot_chord_keys', 'g', 'maj', 'c', 'ionian', 'dominant', 'd', 'dorian', 'subdominant' ],
+  #  [ 'pivot_chord_keys', 'g', 'maj', 'c', 'ionian', 'dominant', 'd', 'ionian', 'subdominant' ],
+  #  [ 'pivot_chord_keys', 'g', 'maj', 'c', 'ionian', 'dominant', 'd', 'mixolydian', 'subdominant' ],
+  #  [ 'pivot_chord_keys', 'g', 'maj', 'c', 'lydian', 'dominant', 'd', 'dorian', 'subdominant' ],
+  #  [ 'pivot_chord_keys', 'g', 'maj', 'c', 'lydian', 'dominant', 'd', 'ionian', 'subdominant' ],
+  #  [ 'pivot_chord_keys', 'g', 'maj', 'c', 'lydian', 'dominant', 'd', 'mixolydian', 'subdominant' ]]
 
 =head1 DESCRIPTION
 
@@ -273,6 +288,8 @@ If defined, the argument in that position will be bound to that value
 
 =head1 SEE ALSO
 
+The F<t/01-methods.t> file in this distribution
+
 L<Moo>
 
 L<AI::Prolog>
@@ -285,6 +302,8 @@ L<Music::Scales>
 
 L<https://en.wikipedia.org/wiki/Prolog>
 
+L<https://en.wikipedia.org/wiki/Common_chord_(music)>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
